<?php
/**
 * Main plugin file. This plugin extends the WooCommerce shop plugin with complete German language packs - formal and informal. - WooCommerce endlich komplett auf deutsch!
 *
 * @package   WooCommerce German (de_DE)
 * @author    David Decker
 * @link      http://twitter.com/#!/deckerweb
 * @copyright Copyright 2012, David Decker - DECKERWEB
 *
 * @credits   Inspired and based on the plugin "WooCommerce (nl)" by Pronamic, NL.
 * @author    Pronamic, NL / Remco Tolsma
 * @link      http://pronamic.eu/
 * @link      http://twitter.com/#!/pronamic
 *
 * Plugin Name: WooCommerce German (de_DE)
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/woocommerce-de/
 * Description: This plugin extends the WooCommerce shop plugin with complete German language packs - formal and informal. - WooCommerce endlich komplett auf deutsch!
 * Version: 1.3
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2 (or later)
 * Text Domain: woocommerce-german
 * Domain Path: /wcde-languages/
 */

/**
 * Setting constants
 *
 * @since 1.0
 */
/** Set constant path to the Plugin basename (folder) */
define( 'WCDE_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_wcde_init' );
/**
 * Load the text domain for translation of the plugin
 * 
 * @since 1.0
 */
function ddw_wcde_init() {

	load_plugin_textdomain( 'woocommerce-german', false, WCDE_PLUGIN_BASEDIR . '/wcde-languages/' );
}


add_filter( 'plugin_row_meta', 'ddw_wcde_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0
 */
function ddw_wcde_plugin_links( $wcde_links, $wcde_file ) {

	if ( !current_user_can( 'install_plugins' ) )
		return $wcde_links;

	if ( $wcde_file == WCDE_PLUGIN_BASEDIR . '/woocommerce-de.php' ) {
		$wcde_links[] = '<a href="http://wordpress.org/extend/plugins/woocommerce-de/faq/" target="_new" title="' . __( 'FAQ', 'woocommerce-german' ) . '">' . __( 'FAQ', 'woocommerce-german' ) . '</a>';
		$wcde_links[] = '<a href="http://wordpress.org/tags/woocommerce-de?forum_id=10" target="_new" title="' . __( 'Support', 'woocommerce-german' ) . '">' . __( 'Support', 'woocommerce-german' ) . '</a>';
		$wcde_links[] = '<a href="' . __( 'http://genesisthemes.de/en/donate/', 'woocommerce-german' ) . '" target="_new" title="' . __( 'Donate', 'woocommerce-german' ) . '">' . __( 'Donate', 'woocommerce-german' ) . '</a>';
	}

	return $wcde_links;
}


/**
 * Main plugin class.
 *
 * All code of this main class by Pronamic, NL, for the "WooCommerce (nl)" plugin
 * @author    Pronamic, NL / Remco Tolsma
 * @copyright Pronamic, NL / Remco Tolsma
 * @license   GPLv2
 * @link      http://pronamic.eu/
 * @link      http://twitter.com/#!/pronamic
 *
 * Modifications needed for German plugin by David Decker (deckerweb).
 *
 * @since 1.0
 * @version 1.1
 */
class WooCommerce_de_DE {

	/**
	 * The current langauge
	 *
	 * @since 1.0
	 *
	 * @var string
	 */
	private static $language;


	/**
	 * Flag for the German langauge
	 * true if current langauge is German, false otherwise
	 *
	 * @since 1.0
	 *
	 * @var boolean
	 */
	private static $_is_german;


	/**
	 * Bootstrap
	 *
	 * @since 1.0
	 */
	public static function bootstrap() {
		add_filter( 'load_textdomain_mofile', array( __CLASS__, 'load_mo_file' ), 10, 2 );
	}


	/**
	 * Check for installed/ used locale and textdomain .mo file
	 * Check for active WPML language code
	 *
	 * @since 1.0
	 *
	 * @param string $moFile
	 * @param string $domain
	 */
	public static function load_mo_file( $moFile, $domain ) {

		// Check for installed/ used locale in WordPress
		if ( self::$language == null ) {
			self::$language = get_option( 'WPLANG', WPLANG );
			self::$_is_german = ( self::$language == 'de_DE' );

			// Check for active WPML language code ("WPML" plugin)
			if (defined( 'ICL_LANGUAGE_CODE' ) ) {
				self::$_is_german = ICL_LANGUAGE_CODE == 'de';
			}
		}

		$newMofile = null;

		/** WooCommerce */
		$_is_woocommerce_domain = ( $domain == 'woocommerce' );

		if ( $_is_woocommerce_domain ) {

			$_is_woocommerce = strpos( $moFile, '/woocommerce/' ) !== false;

			if ( $_is_woocommerce ) {

				$version = get_option( 'woocommerce_db_version', null );

				if ( strpos( $moFile, '/woocommerce/languages/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'sie-version/' );

				} elseif ( strpos( $moFile, '/woocommerce/languages/formal/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'sie-version/' );

				} elseif ( strpos( $moFile, '/woocommerce/languages/informal/woocommerce-' ) !== false ) {
					$newMofile = self::get_mo_file( 'woocommerce', $version, 'du-version/' );
				}

			}  // end-if $_is_woocommerce

		}  // end-if $_is_woocommerce_domain

		if ( is_readable( $newMofile ) ) {
			$moFile = $newMofile;
		}

		return $moFile;

	}  // end of function load_mo_file


	/**
	 * Get the .mo file for the specified domain, version and language
	 *
	 * @since 1.0
	 */
	public static function get_mo_file( $domain, $version, $path = '' ) {

		$dir = dirname( __FILE__ );

		$moFile = $dir . '/languages/' . $domain . '/' . $version . '/' . $path . self::$language . '.mo';

		// If specific version .mo file is not available point to the current public release (cpr) version
		if ( !is_readable( $moFile ) ) {
			$moFile = $dir . '/languages/' . $domain . '/cpr/' . $path . self::$language . '.mo';
		}

		return $moFile;

	}  // end of function get_mo_file

}  // end of main class WooCommerce_de_DE


/** Start class */
WooCommerce_de_DE::bootstrap();
